@@ -4,6 +4,7 @@ import sys
 from strange_case.registry import Registry
 from strange_case.extensions import *
 from strange_case.support import *
+from strange_case.support.fancy_import import fancy_import
 from strange_case.nodes import *
 from strange_case.processors import *
 from strange_case.nodes import Node
@@ -37,18 +38,6 @@ def recommend_package(pkg):
     output_warning("\033[1m" + pkg + "\033[0m is recommend.\n  > pip install " + pkg)
 
 
-def fancy_import(import_name):
-    """
-    This takes a fully qualified object name, like
-    'strange_case.extensions.markdown', and returns the last
-    object.  equivalent to `from strange_case.extensions import markdown`.
-    """
-
-    import_path, import_me = import_name.rsplit('.', 1)
-    imported = __import__(import_path, globals(), locals(), [import_me], -1)
-    return getattr(imported, import_me)
-
-
 def find_files(folder):
     ret = []
     for f in os.listdir(folder):
@@ -128,19 +117,23 @@ def strange_case(config):
                 sys.error.write('Error in processors: Could not find "%s"\n' % processor)
                 raise
         del config['processors']
+    configurators = get_configurators(config)
 
     # register configurators - I broke this out into a separate function (below)
-    for configurator in get_configurators(config):
+    Registry.reset_configurators()
+    for configurator in configurators:
         Registry.add_configurator(configurator)
 
     # configurators can respond to the 'on_start' hook
-    # currently, only the skip_if_not_modified configurator uses this, to
-    # read in the .timestamps file.
-    for configurator in Registry.configurators:
-        try:
-            configurator.on_start(config)
-        except AttributeError:
-            pass
+    # skip_if_not_modified configurator uses this to read in the .timestamps
+    # file, and strip_extensions makes sure that set_url is run before itself.
+    for configurator in configurators:
+        # configurators might be removed (?)
+        if configurator in Registry.configurators:
+            try:
+                configurator.on_start(config)
+            except AttributeError:
+                pass
 
     # each node class should add files to these properties, so that watchdog and
     # stale-file-removal work.
@@ -220,7 +213,6 @@ def get_configurators(config):
         if isinstance(configurator, basestring):
             configurator = fancy_import(configurator)
         configurators.append(configurator)
-    del config['__configurators_pre__']
 
     # load user configurators
     if 'configurators' in config:
@@ -228,7 +220,6 @@ def get_configurators(config):
             if isinstance(configurator, basestring):
                 configurator = fancy_import(configurator)
             configurators.append(configurator)
-        del config['configurators']
 
     # additional configurators, in addition to the all-important defaults
     if 'configurators +' in config:
@@ -243,13 +234,11 @@ However, you will probably want to make sure to include the defaults:
             if isinstance(configurator, basestring):
                 configurator = fancy_import(configurator)
             configurators.append(configurator)
-        del config['configurators +']
 
     # load built-in post configurators
     for configurator in config['__configurators_post__']:
         if isinstance(configurator, basestring):
             configurator = fancy_import(configurator)
         configurators.append(configurator)
-    del config['__configurators_post__']
 
     return configurators
