@@ -1,25 +1,22 @@
 import os
 import re
 
-from strange_case.configurators import provides
-
 
 ORDER_RE = re.compile(r'''
-    ^(?P<order>[0]\d+)
+    ^0+(?P<order>[1-9]\d*)
     [-_]
     (?P<name>.*)
 ''', re.VERBOSE)
 
 
 def strip_order_from(order, name):
-    strip_order_re = re.compile(r'0+{order}[-_]'.format(**locals()))
+    strip_order_re = re.compile(r'^0+{order}[-_]'.format(**locals()))
     match = strip_order_re.search(name)
     if match:
         return name[:match.start()] + name[match.end():]
     return name
 
 
-@provides('order')
 def order_from_name(source_file, config):
     """
     Adds ordering to a file name (when dates aren't quite enough).  The first digit
@@ -29,7 +26,8 @@ def order_from_name(source_file, config):
     matches = ORDER_RE.search(file_name)
     if matches:
         order = int(matches.group('order'))
-        config['order'] = order
+        if 'order' not in config:
+            config['order'] = order
 
         if config['strip_metadata_from_name']:
             config['name'] = strip_order_from(order, config['name'])
